Module value

Module value 

Contains the Value and ValueInner containers into which all toml contents can be deserialized into and either used directly or fed into crate::Deserialize or your own constructs to deserialize into your own types

Structs

Key
A toml table key
Value
A deserialized ValueInner with accompanying Span information for where it was located in the toml document

Enums

ValueInner
The core value types that toml can deserialize to

Type Aliases

Array
A toml array
Table
A toml table, always represented as a sorted map.